==============================
Project hosting with Launchpad
==============================

`Launchpad`_ hosts the Zaqar project. The Zaqar project homepage on Launchpad is
http://launchpad.net/zaqar.

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites. These sites include:

 * `Wiki`_
 * Gerrit (see :doc:`gerrit`)
 * Jenkins (see :doc:`jenkins`)

Mailing list
------------

The mailing list address is ``openstack-discuss@lists.openstack.org``.
This is a common mailing list across all OpenStack projects.
To participate in the mailing list:

   Subscribe at http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

The mailing list archives are at http://lists.openstack.org/pipermail/openstack-dev (pre December 2018) and http://lists.openstack.org/pipermail/openstack-discuss for current.

Bug tracking
------------

Report Zaqar bugs at https://bugs.launchpad.net/zaqar

Feature requests (Blueprints)
-----------------------------

Zaqar uses Launchpad Blueprints to track feature requests. Blueprints are at
https://blueprints.launchpad.net/zaqar.

Technical support (Answers)
---------------------------

Zaqar uses Launchpad Answers to track Zaqar technical support questions. The
Zaqar Answers page is at https://answers.launchpad.net/zaqar.

Note that `Ask OpenStack`_ (which is not hosted on Launchpad) can also be used
for technical support requests.

You can also reach us in ``#openstack-zaqar`` IRC channel at
``irc.freenode.org``.

.. _Launchpad: https://launchpad.net
.. _Wiki: https://wiki.openstack.org
.. _Zaqar Team: https://launchpad.net/zaqar
.. _Ask OpenStack: https://ask.openstack.org/
